# Copyright © 2024 Contrast Security, Inc.
# See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
from contrast.utils.namespace import Namespace  # noqa: provides a cleaner import
from contrast.utils.profiler import Profiler  # noqa: provides a cleaner import
